@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2021-03-19 10:23:13
-@LastEditTime: 2022-02-22 15:41:53
+@LastEditTime: 2022-02-22 16:05:21
 @LastEditors: ChenCheng
 :Description: 奖品
 """
@@ -97,7 +97,7 @@ class PrizeListHandler(ClientBaseHandler):
 
         act_prize_ex_model = ActPrizeExModel(context=self)
 
-        field = "id,prize_name,prize_title,prize_pic,prize_type,tag_id,prize_detail_json,prize_price,yfs_grade,yfs_key_name,sale_status,surplus,prize_total,probability,first_open_threshold,last_open_threshold"
+        field = "id,prize_name,prize_title,prize_pic,prize_type,tag_id,prize_detail_json,prize_price,yfs_type,yfs_grade,yfs_key_name,sale_status,surplus,prize_total,probability,first_open_threshold,last_open_threshold,dd_open_step,dd_open_threshold"
         act_prize_list, total = act_prize_ex_model.get_dict_page_list(field, page_index, page_size, "module_id=%s and is_del=0 and is_release=1", "", "sort_index desc", module_id)
 
         prize_sum_probability = 0  # 奖品总权重
